@@ -5,7 +5,7 @@ to output log data as JSON formatted strings
 import logging
 import json
 import re
-from datetime import date, datetime, time
+from datetime import date, datetime, time, timezone
 import traceback
 import importlib
 
@@ -154,7 +154,7 @@ class JsonFormatter(logging.Formatter):
 
         if self.timestamp:
             key = self.timestamp if type(self.timestamp) == str else 'timestamp'
-            log_record[key] = datetime.utcnow()
+            log_record[key] = datetime.fromtimestamp(record.created, tz=timezone.utc)
 
     def process_log_record(self, log_record):
         """
@@ -171,6 +171,10 @@ class JsonFormatter(logging.Formatter):
                                     indent=self.json_indent,
                                     ensure_ascii=self.json_ensure_ascii)
 
+    def serialize_log_record(self, log_record):
+        """Returns the final representation of the log record."""
+        return "%s%s" % (self.prefix, self.jsonify_log_record(log_record))
+
     def format(self, record):
         """Formats a log record and serializes to json"""
         message_dict = {}
@@ -206,4 +210,4 @@ class JsonFormatter(logging.Formatter):
         self.add_fields(log_record, record, message_dict)
         log_record = self.process_log_record(log_record)
 
-        return "%s%s" % (self.prefix, self.jsonify_log_record(log_record))
+        return self.serialize_log_record(log_record)
